#include <zephyr/kernel.h>
#include <zephyr/sys/printk.h>
#include <zephyr/logging/log.h>
#include <zephyr/device.h>
#include <zephyr/drivers/gpio.h>
#include <zephyr/types.h>

LOG_MODULE_REGISTER(main_file);
#define BUTTON0_NODE DT_ALIAS(button0pin)

static struct gpio_callback button_cb_data;
static const struct gpio_dt_spec button_0 = GPIO_DT_SPEC_GET(BUTTON0_NODE, gpios);

static struct k_timer button_timer;
static bool long_press_detected = false;

void long_button_pressed(const struct device *dev, struct gpio_callback *cb, uint32_t pins)
{
   // if (gpio_pin_get_dt(&button_0)) {
    if(pins & BIT(button_0.pin)){
        LOG_INF("button pin detected");
        k_timer_start(&button_timer, K_SECONDS(10), K_NO_WAIT);
    } else {
        LOG_INF("long_press not detected");
        k_timer_stop(&button_timer);
        long_press_detected = false;  // Reset flag if button is released
    }
}

void button_timer_expiry_handler(struct k_timer *timer_id)
{
    LOG_INF("Button long-pressed for 10 seconds\n");
    // Add your action here
}

void long_press_button(){
    if (!device_is_ready(button_0.port)) {
        printk("Button device not ready\n");
        return;
    }
    gpio_init_callback(&button_cb_data,long_button_pressed, BIT(button_0.pin));
    LOG_INF("long_press");
    gpio_add_callback(button_0.port, &button_cb_data);

    k_timer_init(&button_timer, button_timer_expiry_handler, NULL);

}

void bsp_button_init(){

    uint8_t ret;

    if(!device_is_ready(button_0.port)){
        LOG_INF("button init failed");
    }

    // configure button gpio as input
    ret = gpio_pin_configure_dt(&button_0, GPIO_INPUT);
    if (ret < 0) {
        return;
    }
    ret = gpio_pin_interrupt_configure_dt(&button_0, GPIO_INT_EDGE_RISING);
    if (ret < 0) {
        return;
    }

}

int main(void)
{
    bsp_button_init();
    long_press_button();
    return 0;
}
